/*
 * The Qubes OS Project, http://www.qubes-os.org
 *
 * Copyright (C) 2013  Marek Marczykowski <marmarek@invisiblethingslab.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#ifndef LIBVCHAN_PRIVATE_H
#define LIBVCHAN_PRIVATE_H

#include <libxenvchan.h>

struct libvchan {
    struct libxenvchan *xenvchan;
    /* store path, which should be removed after client connect (server only) */
    char *xs_path;
    int remote_domain;
    xc_interface *xc_handle;
};

int libvchan__check_domain_alive(xc_interface *xc_handle, int dom);

#endif
